div.control
{
    float: left;
}

div#stylecontrol
{
    margin-left: 20px;
}

div#stylecontrol
{
    width: 200px;
}

div.clear
{
    clear: both;
}

div#linenostartcontrol
{
    margin-left: 10px;
    margin-top: 5px;
}

div#highlightcontrol
{
   margin-top: 10px;
   margin-bottom: 10px;
}

input#linenos
{
    position: relative;
    top: 3px;
}

input#srcattach
{
    position: relative;
    top: 3px;
}

div#sourceattachcontrol
{
    width: 100%;
}

.tabbutton
{
    margin: 0px;
    padding: 0px;
    float: left;
    border-bottom: none;
}

input.inactive
{
    background-color: #aaaaaa;
}

div#tab-container
{
    margin: 0px;
    padding: 0px;

}

div#codetab
{
    margin: 0px;
    padding: 0px;
}

div#previewcontent
{
    min-width: 300px;
    min-height: 160px;
    background: #ffffff;
    border: 1px solid #000000;
    margin-top: 1px;
}
