(function(){tinymce.create('tinymce.plugins.PygmentsPlugin',{init:function(ed,url){ed.addCommand('mcePygments',function(){ed.windowManager.open({file:'/pygments/renderer',inline:1, width:550, height: 360},{plugin_url:url})});ed.addButton('pygments',{title:'Insert code with Pygments',cmd:'mcePygments',image:url+'/img/pygments.gif'});ed.onNodeChange.add(function(ed,cm,n){cm.setActive('pygments',n.nodeName=='IMG')})},createControl:function(n,cm){return null},getInfo:function(){return{longname:'Pygments plugin',author:'Chen Zhe',authorurl:'http://www.fruitschen.com',infourl:'http://www.fruitschen.com',version:"0.1"}}});tinymce.PluginManager.add('pygments',tinymce.plugins.PygmentsPlugin)})();
